@@ -16,7 +16,8 @@ from unittest import TestCase, main
 import numpy as np
 import numpy.testing as npt
 
-from biom.parse import generatedby, MetadataMap, parse_biom_table, parse_uc
+from biom.parse import (generatedby, MetadataMap, parse_biom_table, parse_uc,
+                        load_table)
 from biom.table import Table
 from biom.util import HAVE_H5PY, __version__
 from biom.tests.long_lines import (uc_empty, uc_invalid_id, uc_minimal,
@@ -228,6 +229,51 @@ class ParseTests(TestCase):
         self.assertEqual(tab.metadata(), None)
         self.assertEqual(tab.metadata(axis='observation'), None)
 
+    def test_parse_adjacency_weird_input(self):
+        with self.assertRaisesRegex(ValueError, "Not sure"):
+            Table.from_adjacency({'foo', 'bar'})
+
+    def test_parse_adjacency_bad_input(self):
+        with self.assertRaisesRegex(ValueError, "Does not appear"):
+            Table.from_adjacency(['a\tb\tc\n', 'd\te\tf\n'])
+
+        with self.assertRaisesRegex(ValueError, "Does not appear"):
+            Table.from_adjacency(['a\tb\n', 'd\te\n'])
+
+        with self.assertRaises(AssertionError):
+            Table.from_adjacency(['a\tb\t1\n', 'd\te\n'])
+
+    def test_parse_adjacency_table_header(self):
+        lines = ['#OTU ID\tSampleID\tvalue\n',
+                 'O1\tS1\t10\n',
+                 'O4\tS2\t1\n',
+                 'O3\tS3\t2\n',
+                 'O4\tS1\t5\n',
+                 'O2\tS2\t3\n']
+        exp = Table(np.array([[10, 0, 0],
+                              [0, 3, 0],
+                              [0, 0, 2],
+                              [5, 1, 0]]),
+                    ['O1', 'O2', 'O3', 'O4'],
+                    ['S1', 'S2', 'S3'])
+        obs = Table.from_adjacency(''.join(lines))
+        self.assertEqual(obs, exp)
+
+    def test_parse_adjacency_table_no_header(self):
+        lines = ['O1\tS1\t10\n',
+                 'O4\tS2\t1\n',
+                 'O3\tS3\t2\n',
+                 'O4\tS1\t5\n',
+                 'O2\tS2\t3\n']
+        exp = Table(np.array([[10, 0, 0],
+                              [0, 3, 0],
+                              [0, 0, 2],
+                              [5, 1, 0]]),
+                    ['O1', 'O2', 'O3', 'O4'],
+                    ['S1', 'S2', 'S3'])
+        obs = Table.from_adjacency(''.join(lines))
+        self.assertEqual(obs, exp)
+
     @npt.dec.skipif(HAVE_H5PY is False, msg='H5PY is not installed')
     def test_parse_biom_table_hdf5(self):
         """Make sure we can parse a HDF5 table through the same loader"""
@@ -237,6 +283,32 @@ class ParseTests(TestCase):
         Table.from_hdf5(h5py.File('test_data/test.biom'))
         os.chdir(cwd)
 
+    @npt.dec.skipif(HAVE_H5PY is False, msg='H5PY is not installed')
+    def test_load_table_filepath(self):
+        cwd = os.getcwd()
+        if '/' in __file__[1:]:
+            os.chdir(__file__.rsplit('/', 1)[0])
+        load_table('test_data/test.biom')
+        os.chdir(cwd)
+
+    @npt.dec.skipif(HAVE_H5PY is False, msg='H5PY is not installed')
+    def test_load_table_inmemory(self):
+        cwd = os.getcwd()
+        if '/' in __file__[1:]:
+            os.chdir(__file__.rsplit('/', 1)[0])
+        load_table(h5py.File('test_data/test.biom'))
+        os.chdir(cwd)
+
+    def test_load_table_inmemory_json(self):
+        cwd = os.getcwd()
+        if '/' in __file__[1:]:
+            os.chdir(__file__.rsplit('/', 1)[0])
+        load_table(open('test_data/test.json'))
+        os.chdir(cwd)
+
+    def test_load_table_inmemory_stringio(self):
+        load_table(StringIO('\n'.join(self.classic_otu_table1_no_tax)))
+
     def test_parse_biom_table(self):
         """tests for parse_biom_table when we do not have h5py"""
         # This is a TSV as a list of lines
