@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 # ----------------------------------------------------------------------------
-# Copyright (c) 2011-2017, The BIOM Format Development Team.
+# Copyright (c) 2011-2020, The BIOM Format Development Team.
 #
 # Distributed under the terms of the Modified BSD License.
 #
@@ -37,7 +37,7 @@ except ImportError:
 from numpy import mean, median, min, max
 
 __author__ = "Daniel McDonald"
-__copyright__ = "Copyright 2011-2017, The BIOM Format Development Team"
+__copyright__ = "Copyright 2011-2020, The BIOM Format Development Team"
 __credits__ = ["Daniel McDonald", "Jai Ram Rideout", "Greg Caporaso",
                "Jose Clemente", "Justin Kuczynski", "Jorge Cañardo Alastuey"]
 __license__ = "BSD"
@@ -45,7 +45,7 @@ __url__ = "http://biom-format.org"
 __maintainer__ = "Daniel McDonald"
 __email__ = "daniel.mcdonald@colorado.edu"
 __format_version__ = (2, 1)
-__version__ = "2.1.8"
+__version__ = "2.1.10"
 
 
 def generate_subsamples(table, n, axis='sample', by_id=False):
@@ -202,9 +202,9 @@ def prefer_self(x, y):
     return x if x is not None else y
 
 
-def index_list(l):
+def index_list(item):
     """Takes a list and returns {l[idx]:idx}"""
-    return dict([(id_, idx) for idx, id_ in enumerate(l)])
+    return dict([(id_, idx) for idx, id_ in enumerate(item)])
 
 
 def load_biom_config():
